@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.314';
+$VERSION = '3.316';
 
 ######################################################################
 #### Error Handling
@@ -139,6 +139,15 @@ sub new_module {
     return $modref;
 }
 
+sub new_root_module {
+    my $self = shift;
+    $self->{_modules}{'$root'} ||=
+	$self->new_module(keyword=>'root_module',
+			  name=>'$root',
+			  @_);
+    return $self->{_modules}{'$root'};
+}
+
 sub defvalue_nowarn {
     my $self = shift;
     my $sym = shift;
@@ -581,6 +590,11 @@ be first, the top most module will be last.
 
 Creates a new Verilog::Netlist::Module.
 
+=item $netlist->new_root_module
+
+Creates a new Verilog::Netlist::Module for $root, if one doesn't already
+exist.
+
 =item $netlist->top_modules_sorted
 
 Returns name sorted list of Verilog::Netlist::Module, only for those
