@@ -12,7 +12,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.313';
+$VERSION = '3.316';
 
 structs('new',
 	'Verilog::Netlist::File::Struct'
@@ -249,7 +249,7 @@ sub var {
     my $value = shift;
     print " Sig $name dt=$decl_type nt=$net_type d=$data_type\n" if $Verilog::Netlist::Debug;
 
-    return if !($objof eq 'module' || $objof eq 'interface' || $objof eq 'modport');
+    return if !($objof eq 'module' || $objof eq 'interface' || $objof eq 'modport' || $objof eq 'netlist');
 
     my $msb;
     my $lsb;
@@ -260,6 +260,10 @@ sub var {
     }
 
     my $underref = $self->{_modportref} || $self->{modref};
+    if ($objof eq 'netlist') {
+	$underref = $self->{netlist}->new_root_module
+	    (filename=>$self->filename, lineno=>$self->lineno);
+    }
     if (!$underref) {
 	return $self->error ("Signal declaration outside of module definition", $name);
     }
@@ -529,7 +533,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2011 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2012 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
